# do not remove the { } from the top and bottom of this page!!!
{

#Icelandic translation done by Gudmundur A. Thorisson <mummi@cshl.edu>

#$Id: is.pm,v 1.7 2006-07-14 12:38:52 lstein Exp $

 CHARSET =>   'ISO-8859-1',

   #----------
   # MAIN PAGE
   #----------

   PAGE_TITLE => 'Genome browser',
   
   SEARCH_INSTRUCTIONS => <<END,
Leiti a nafni  r, nafni  geni, lkus ea ru kennileiti. Hgt er a nota * (e. wildcard) fyrir frjlsa leit.
END

   NAVIGATION_INSTRUCTIONS => <<END,
Til a mija  stasetningu, smelli  stikuna. Noti Skrun/Zoom takkana til a breyta stkkun og stasetningu
END

   EDIT_INSTRUCTIONS => <<END,
Hr m breyta vistuum annoteringum. Hgt er a nota innslttartkni (e. tab) ea stafabil til a askilja reiti, en reitir sem innihalda stafabil urfa a vera innan einfaldra ea tvfaldra gsalappa.
END

   SHOWING_FROM_TO => 'Sni %s  %s,fr %s til %s',

   INSTRUCTIONS      => 'Leibeiningar',

   HIDE              => 'Fela',
   
   SHOW              => 'Sna',

   SHOW_INSTRUCTIONS => 'Sna leibeiningar',

   HIDE_INSTRUCTIONS => 'Fela leibeiningar',

   SHOW_HEADER       => 'Sna haus',

   HIDE_HEADER       => 'Fela haus',

   LANDMARK => 'Kennileiti ea svi',

   BOOKMARK => 'Vista sem bkamerki',

   IMAGE_LINK => 'F vefsl  mynd',

   SVG_LINK   => 'Mynd sem hentar til birtingar',

   SVG_DESCRIPTION => <<END,
<p>
Eftirfarandi sl mynd br til essa smu mynd  Scalable Vector Graphic (SVG) snii. SVG bur upp  nokkra umfram "raster"-byggar myndir eins og jpeg ea png.
</p>
<ul>
<li>hgt a breyta str n ess a tapa upplausn
<li>hgt a vinna me myndirnar  myndvinnsluforritum sem hndla vector-grafk, til dmis fra til annoteringar ef vill
<li>ef nausyn krefur er hgt a breyta yfir  EPS-sni til a senda til birtingar  vsindaritum
</ul>
<p>
Til a skoa SVG-myndir arftu a hafa vafra sem styur SVG-snii, td. Adobe "plugin" fyrir vefvafra, ea Adobe Illustrator myndvinnsluforriti.
</p>
<p>
Adobe "plugin": <a
href="http://www.adobe.com/support/downloads/product.jsp?product=46&platform=Macintosh">Macintosh</a>
| <a
href="http://www.adobe.com/support/downloads/product.jsp?product=46&platform=Windows">Windows</a>
<br />
Linuxnotendur geta skoa ennan hr: <a href="http://xml.apache.org/batik/">Batik SVG Viewer</a>.
</p>
<p>
<a href="%s" target="_blank">Skoa SVG-mynd  njum vafraglugga</a></p>
<p>
Til a vista essa mynd  hara diskinn hj r, Ctrl-klikkau (Macintosh) ea hgri-klikkau (Windows) og veldu "Save link to disk".
</p>   
END

   IMAGE_DESCRIPTION => <<END,
<p>
Til a setja essa mynd  heimasu, afriti essa vefsl og setji  HTML-kann svona:
</p>
<pre>
&lt;IMAGE src="%s" /&gt;
</pre>
<p>
Myndin mun lta svona t:
</p>
<p>
<img src="%s" />
</p>

<p>
Ef aeins yfirlitsmyndin  sst a ofan, reyni a minnka strina  svinu</p>
END

   TIMEOUT  => <<'END',
Fyrirspurn n tk of langan tma.  gtir hafa vali svi sem er of strt til a sna. Prfau a slkkva  einhverjum brautanna, ea minnka svi. Ef etta gerist trekk  trekk, vinsamlega ttu  "Endursetja" takkann.
END

   GO       => 'Keyra',

   FIND     => 'Finna',

   SEARCH   => 'Leita',

   DUMP     => 'Vista',

   HIGHLIGHT => 'Merkja',

   ANNOTATE     => 'Annotera',

   SCROLL   => 'Skrun/Zoom',

   RESET    => 'Endursetja',

   FLIP     => 'Sna vi',

   DOWNLOAD_FILE    => 'Vista skr',

   DOWNLOAD_DATA    => 'Vista ggn',

   DOWNLOAD         => 'Vista',

   DISPLAY_SETTINGS => 'Stillinga glugga',

   TRACKS   => 'Brautir',

   EXTERNAL_TRACKS => "(Utanakomandi brautir skletraar)<br><sup>*</sup>Yfirlitsbraut",

   OVERVIEW_TRACKS => '<sup>*</sup>Yfirlitsbraut',

   REGION_TRACKS  => '<sup>**</sup>Svisbraut',

   EXAMPLES => 'Dmi',

   REGION_SIZE  => 'Str svis (bp)',

   HELP     => 'Hjlp',

   HELP_FORMAT => 'Hjlp fyrir skjsni',

    CANCEL   => 'Htta vi',

   ABOUT    => 'Um...',

   REDISPLAY   => 'Sna aftur',

   CONFIGURE   => 'Stillingar...',

   EDIT       => 'Breyta skr...',

   DELETE     => 'Eya skr',

   EDIT_TITLE => 'Bta vi ea breyta annoteringum',

   IMAGE_WIDTH => 'Breidd myndar',

   BETWEEN     => 'Milli',

   BENEATH     => 'Undir',

   LEFT        => 'Vinstri',

   RIGHT       => 'Hgri',

   TRACK_NAMES => 'Tafla yfir nfn  brautum',

   ALPHABETIC  => 'Stafrfsr',

   VARYING     => 'Breytilegt',

   SET_OPTIONS => 'Breyta stillingum fyrir brautir...',

   UPDATE      => 'Uppfra mynd',

   DUMPS       => 'Dump, leitir og arar agerir',

   DATA_SOURCE => 'Gagnalind',

   UPLOAD_TRACKS  => 'Bta vi eigin brautum',

   UPLOAD_TITLE=> 'Vista eigin annoteringar  vef',

   UPLOAD_FILE => 'Vista eigin skr  vef',

   KEY_POSITION => 'Stasetning lykils',

   BROWSE      => 'Vafra...',

   UPLOAD      => 'Hlaa upp',

   NEW         => 'Ntt...',

   REMOTE_TITLE => 'Bta vi eigin annoteringum',

   REMOTE_URL   => 'Sl inn vefsl fyrir utanakomandi annoteringar',

   UPDATE_URLS  => 'Uppfra vefslir',

   PRESETS      => '--Velja fyrirfram uppsettar vefslir--',

   FEATURES_TO_HIGHLIGHT  => 'Kennileiti sem merkja  (kennileiti1, kennileiti2...)',
     
   FEATURES_TO_HIGHLIGHT_HINT  => 'Vsbending: notau kennileiti@litur til a velja litinn, t.d. \'NUT21@lightblue\' ',

   REGIONS_TO_HIGHLIGHT  => 'Merkja svi (svi1:start..end svi2:start..end)',
    
   REGIONS_TO_HIGHLIGHT_HINT  => 'Vsbending: notau svi@litur, t.d. \'Chr1:1000..2000@lightblue\'',

   NO_TRACKS  => '*engar*',

   FILE_INFO    => 'Sast uppfrt %s.  Annoteru kennileiti: %s',

   FOOTER_1     => <<END,
ATH: essi sa notar "smkkur" (e. cookies) til a a vista og endurheimta stillingar. Engum upplsingum er deilt me utanakomandi ailum
END

   FOOTER_2    => 'Generic genome browser version %s',

   #----------------------
   # MULTIPLE MATCHES PAGE
   #----------------------

   HIT_COUNT      => 'Eftirfarandi %d svi samsvara fyrirspurninni.',

   POSSIBLE_TRUNCATION  => 'Niurstur leitur eru takmarkair vi %s atrii; listinn er hugsanlega ekki tmandi',

   MATCHES_ON_REF => ' Fundi  %s',

   SEQUENCE        => 'r;',

   SCORE           => 'skor=%s',

   NOT_APPLICABLE => 'n/a',

   BP             => 'bp',

   #--------------
   # SETTINGS PAGE
   #--------------

   SETTINGS => 'Stillingar fyrir %s',

   UNDO     => 'Afturkalla breytingar',

   REVERT   => 'Breyta yfir i sjlfgefnar stillingar',

   REFRESH  => 'Hlaa su aftur',

   CANCEL_RETURN   => 'Htta vi breytingar og fara til baka...',

   ACCEPT_RETURN   => 'Virkja breytingar og fara til baka...',

   OPTIONS_TITLE => 'Brautarstillingar',

   SETTINGS_INSTRUCTIONS => <<END,
 <i>Sna</i> segir til um hvort braut er snileg ea ekki.
 <I>Samjappa</i> jappar brautinni saman a eina lnu
 annig a annoteringar munu skarast. 
<i>Breia r</i> og <i>Breia meira r</i>  hindra annoteringar  a rekast
 hver  ara, me  hgvirkari og hravirkari algorithmum
 <i>Breia r & merkja</i> og  <i>Breia meira r & mergja</i>  setur 
merki (e. labels)  allar annoteringar. Ef <i>Sjlfvirkt</i> er vali 
eru rekstrar- og merkjastillingar settar eftir v sem plss leyfir.
 Til a breyta v hvernig brautirnar raast upp, noti <i>Breyta uppun brauta</i>
 til a setja tiltekna annoteringu  brautina. Til a takmarka hversu margar 
annoteringar af tiltekinni tegund eru sndar, noti 
<i>Takmarka fjlda</i> valmyndina.
END

   TRACK  => 'Braut',

   TRACK_TYPE => 'Tegund brautar',

   SHOW => 'Sna',

   FORMAT => 'Sni',

   LIMIT  => 'Takmarka fjlda',

   ADJUST_ORDER => 'Stilla upprun brauta',

   CHANGE_ORDER => 'Breyta upprun brauta',

   AUTO => 'Sjlfvirkt',

   COMPACT => 'Samjappa',

   EXPAND => 'Breia r',

   EXPAND_LABEL => 'Breia r & merkja',

   HYPEREXPAND => 'Breia meira r',

   HYPEREXPAND_LABEL =>'Breia meira r & merkja',

   NO_LIMIT    => 'Engin takmrkun',
       
   OVERVIEW  => 'Yfirlit',

  GENERAL => 'Almennt',

   DETAILS  => 'Nnar',

   ALL_ON => 'Virkja allar',

   ALL_OFF  => 'Afvirkja allar',

   ANALYSIS  => 'Greining',

   REGION  => 'Svi',
    

   #--------------
   # HELP PAGES
   #--------------

   CLOSE_WINDOW => 'Loka essum glugga',

   TRACK_DESCRIPTIONS => 'Lsingar og titlar  brautum',

   BUILT_IN           => 'Brautir innbyggar  ennan vefjn',

   EXTERNAL           => 'Utanakomandi annoteringarbrautir',

   ACTIVATE           => 'Vinsamlega virkji essa braut til a sj hva er  henni...',

   NO_EXTERNAL        => 'Engar utanakomandi annoteringar hlanar inn.',

   NO_CITATION        => 'Engar frekari upplsingar fanlegar.',

   #--------------
   # PLUGIN PAGES
   #--------------

 ABOUT_PLUGIN  => 'Um %s',

 BACK_TO_BROWSER => 'Aftur til GBrowse',

 PLUGIN_SEARCH_1   => '%s (leit me %s)',

 PLUGIN_SEARCH_2   => '&lt;%s leit&gt;',

 CONFIGURE_PLUGIN   => 'Stilla',

 BORING_PLUGIN => 'essi plugin hefur engar auka stillimguleika.',

   #--------------
   # ERROR MESSAGES
   #--------------

 NOT_FOUND => 'Kennileiti <i>%s</i> fannst ekki. Sj hjlparsur fyrir uppstungur.',

 TOO_BIG   => 'Nnari sn er takmrku vi %s bp.  Smelli  yfirlitsmyndina til velja svi
   sem er %s bp a str.',

 PURGED    => "Finn ekki skrna %s. Hefur henni veri hent?",

 NO_LWP    => "essi vefjnn er ekki stilltur til a n  utanakomandi vefslir",

 FETCH_FAILED  => "Gat ekki n  %s: %s.",

 TOO_MANY_LANDMARKS => '%d kennileiti.  Of mrg til a telja upp!.',

 SMALL_INTERVAL    => 'Breyti str svis  %s bp',
          
CLEAR_HIGHLIGHTING  => 'Fjarlgja merkingar',

CONFIGURE_TRACKS  => 'Stilla brautir...', 
     
NO_SOURCES  => 'Engar agengilegar gagnalindir stilltar. Kannske hefur  ekki leyfi til a skoa r',

};

